C$Procedure      ADDLNK ( Add a new AB cell to the linked list )
 
      SUBROUTINE ADDLNK ( AVAL, BVAL, PNTRS, NCELL, CELLS )
 
C$ Abstract
C
C     Open and add a new AB cell to the linked-list and
C     update the A-value pointer array.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     AB linked list
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               AVAL
      INTEGER               BVAL
      INTEGER               NCELL
      INTEGER               PNTRS  ( * )
      INTEGER               CELLS  ( 3, * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVAL       I   A-value to put in new cell.
C     BVAL       I   B-value to put in new cell.
C     PNTRS     I/O  A-value pointer array to update.
C     NCELL     I/O  Number of cells in AB cell linked-list.
C     CELL      I/O  Cell array.
C
C$ Detailed_Input
C
C     AVAL       A-value to be placed in new cell.
C
C     BVAL       Associated B-value to be placed in new cell.
C
C     PNTRS      Pointers to last cell containing a given A-value.
C                Updated on output.
C
C     NCELL      Number of cells, incremented by one on output.
C
C     CELL       Cell array, updated on output.
C
C$ Detailed_Output
C
C     PNTRS      See Detailed_Input.
C     NCELL      See Detailed_Input.
C     CELL       See Detailed_Input.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     AB linked list
C
C-&
 
      INTEGER               PTR
 
C
C     Increment the cell counter.
C
      NCELL = NCELL + 1
 
 
C
C     Obtain the cell address of the last occurence of the A-value.
C
      PTR = PNTRS(AVAL)
 
      IF( PTR .EQ. -1 ) THEN
 
C
C     No cells with containing the A-value exists; start a new thread.
C
         CELLS(1,NCELL) = AVAL
         CELLS(2,NCELL) = BVAL
         CELLS(3,NCELL) = -1
 
      ELSE
 
C
C     Update the last cell with the previous cell address.
C
         CELLS(1,NCELL) = AVAL
         CELLS(2,NCELL) = BVAL
         CELLS(3,NCELL) = PTR
 
      END IF
 
      PNTRS(AVAL) = NCELL
 
 
      RETURN
      END
