C$Procedure      TRVLNK ( Traverse AB cell linked-list )
 
      SUBROUTINE TRVLNK ( AVAL, PNTRS, CELLS, NB, BLIST )
 
C$ Abstract
C
C     Traverse the linked list, searching for
C     all cells that contain the A-value.
C     Store the associated B-values in an array.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     linked list
C
C$ Declarations
 
      IMPLICIT NONE
 
      INTEGER               NB
      INTEGER               AVAL
      INTEGER               PNTRS  ( * )
      INTEGER               BLIST  ( * )
      INTEGER               CELLS  ( 3, * )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVAL       I   A-value.
C     PNTRS      I   Array of pointers to the last occurrence of
C                    an A-value in the AB cell linked list CELLS.
C     CELLS      I   Cells containing A, B values and backward pointers.
C     NB         O   Number of B values found.
C     BLIST      O   List of B values.
C
C$ Detailed_Input
C
C     AVAL       A-value.
C
C     PNTRS      Array containing the pointer to the last
C                entry in CELLS containing a particular A-value.
C
C     CELLS      Cells containing an A-value, an associated B-value
C                and a backward pointer to the cell (if any)
C                containing the same A-value.
C
C$ Detailed_Output
C
C     NB         Number of associated B-values found.
C
C     BLIST      List of associated B-values.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     NOT Error free.
C
C$ Particulars
C
C     Later.
C
C$ Examples
C
C     Later.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.1, 26-AUG-2002 (BVS)
C
C        Replaced WRITE with normal error reporting calls.
C
C-    SPICELIB Version 1.0.0, 03-FEB-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     AB cells
C
C-&
 
      LOGICAL               RETURN
 
      INTEGER               I
      INTEGER               PTR
 
C
C     Standard SPICE error handling.
C
 
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN  ( 'TRVLNK' )
 
C
C     Walk backword through the linked list.
C
 
      NB = 0
      PTR = PNTRS(AVAL)
 
      DO WHILE( PTR .NE. -1 )
 
         IF( CELLS(1,PTR) .EQ. AVAL ) THEN
 
            NB = NB + 1
            BLIST(NB) = CELLS(2,PTR)
 
            I   = CELLS(3,PTR)
            PTR = I
 
         ELSE
 
            CALL SETMSG ( 'TRVLNK: A-value mismatch. '   //
     .                    'AVAL = #; PTR = #; '          //
     .                    'CELLS(1,PTR) = #. '           )
            CALL ERRINT ( '#',  AVAL                     )
            CALL ERRINT ( '#',  PTR                      )
            CALL ERRINT ( '#',  CELLS(1,PTR)             )
            CALL SIGERR ( 'SPICE(AVALUEMISMATCH)'        )
            CALL CHKOUT ( 'TRVLNK'                       )
            RETURN
 
         END IF
 
      END DO
 
C
C     Standard SPICE error handling.
C
 
      CALL CHKOUT ( 'TRVLNK' )
 
      RETURN
      END
