C$Procedure      POVTRI ( Output a colored triangle to a POV file )

      SUBROUTINE POVTRI ( FUNIT, PLTID, COLCH )

C$ Abstract
C
C     Output a colored triangle to a POV file.
C
C$ Copyright
C
C     Copyright (2002), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE MODEL
C
C$ Declarations

      IMPLICIT NONE

      INTEGER               PLTID
      INTEGER               FUNIT

      CHARACTER*(*)         COLCH

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FUNIT      I   Output file unit
C     PLTID      I   Plate ID
C     COLCH      I   Color
C
C$ Detailed_Input
C
C     FUNIT          is the output text file unit; must be attached to
C                    a text file opened for write access.
C
C     PLTID          is the plate ID.
C
C     COLCH          is a string specifying plate color; must be
C                    one of the 16 basic colors supported by POV
C                    ('gray', 'red', etc.)
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     TBD.
C
C$ Exceptions
C
C     TBD.
C
C$ Particulars
C
C     TBD.
C
C$ Examples
C
C     See SPINPLAT program calling this routine.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof        (JPL)
C     B.V. Semenov      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPINPLAT Version 1.1.0, 25-AUG-2002 (BVS)
C
C        Added half-baked header. Added check in/out.
C
C-    SPINPLAT Version 1.0.0, DD-MMM-YYYY (JAB)
C
C        Initial version.
C
C-&

C
C     SPICELIB functions.
C
      LOGICAL               RETURN

C
C     Local declarations.
C
      INTEGER               I
      INTEGER               J

      DOUBLE PRECISION      VERT3   ( 3, 3 )

      CHARACTER*(300)       OUTLIN
      CHARACTER*(20)        VECT      ( 3 , 3 )

C
C     Check in.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF

      CALL CHKIN ( 'POVTRI' )

C
C     The code.
C
      OUTLIN = ' '

      CALL NTHPLV ( PLTID, VERT3 )

      DO I = 1, 3
         DO J = 1, 3
            CALL DPSTR ( VERT3(J,I), 8, VECT(J,I) )
         END DO
      END DO

      OUTLIN =   'triangle {<#,#,#>,<#,#,#>,<#,#,#> '
     .        // ' texture { # } }'

      DO I = 1, 3
         DO J = 1, 3
            CALL REPMC ( OUTLIN, '#', VECT(J,I), OUTLIN )
         END DO
      END DO

      CALL REPMC ( OUTLIN, '#', COLCH, OUTLIN )

      CALL WRITLN ( OUTLIN, FUNIT )

C
C     Check out.
C
      CALL CHKOUT ( 'POVTRI' )

      RETURN
      END

